#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of ARIA switch presentation."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))
sequence.append(KeyComboAction("<Control>Home"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "1. Tab to switch",
    ["BRAILLE LINE:  '& y Power saving switch'",
     "     VISIBLE:  '& y Power saving switch', cursor=1",
     "SPEECH OUTPUT: 'Power saving switch off'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction(" "))
sequence.append(utils.AssertPresentationAction(
    "2. Change state of switch",
    ["BRAILLE LINE:  '&=y Power saving switch'",
     "     VISIBLE:  '&=y Power saving switch', cursor=1",
     "SPEECH OUTPUT: 'on'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction(" "))
sequence.append(utils.AssertPresentationAction(
    "3. Change state of switch",
    ["BRAILLE LINE:  '& y Power saving switch'",
     "     VISIBLE:  '& y Power saving switch', cursor=1",
     "SPEECH OUTPUT: 'off'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "4. Basic whereAmI",
    ["BRAILLE LINE:  '& y Power saving switch'",
     "     VISIBLE:  '& y Power saving switch', cursor=1",
     "SPEECH OUTPUT: 'Power saving switch off'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
    "5. Up arrow",
    ["BRAILLE LINE:  'Line 1'",
     "     VISIBLE:  'Line 1', cursor=1",
     "SPEECH OUTPUT: 'Line 1'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "6. Down arrow",
    ["BRAILLE LINE:  'Line 2: & y Power saving switch'",
     "     VISIBLE:  'Line 2: & y Power saving switch', cursor=1",
     "SPEECH OUTPUT: 'Line 2:'",
     "SPEECH OUTPUT: 'Power saving switch off'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
