#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of presentation when typing in a cell."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("Tab"))
sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
sequence.append(PauseAction(3000))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction("h"))
sequence.append(utils.AssertPresentationAction(
    "1. Type 'h' - keyecho is off",
    ["BRAILLE LINE:  'soffice application Untitled 1 - LibreOffice Calc root pane Untitled 1 - LibreOffice Spreadsheets Cell A1 panel h $l'",
     "     VISIBLE:  'h $l', cursor=2",
     "BRAILLE LINE:  'soffice application Untitled 1 - LibreOffice Calc root pane Formula Tool Bar tool bar Input line Input line $l h $l'",
     "     VISIBLE:  'h $l', cursor=1"]))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction("i"))
sequence.append(utils.AssertPresentationAction(
    "2. Type 'i' - keyecho is off",
    ["BRAILLE LINE:  'soffice application Untitled 1 - LibreOffice Calc root pane Untitled 1 - LibreOffice Spreadsheets Cell A1 panel hi $l'",
     "     VISIBLE:  'hi $l', cursor=3"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Return"))
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
    "3. Press Return",
    ["BRAILLE LINE:  'soffice application Untitled 1 - LibreOffice Calc root pane Untitled 1 - LibreOffice Spreadsheets Sheet Sheet1 table  A2'",
     "     VISIBLE:  'table  A2', cursor=7",
     "SPEECH OUTPUT: 'blank A2.'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
