#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test to verify presentation of selectable list items."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("<Control><Shift>n"))
sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("Tab"))
sequence.append(PauseAction(3000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "1. Tab to combo box",
    ["BRAILLE LINE:  'soffice application Templates dialog All Categories combo box'",
     "     VISIBLE:  'All Categories combo box', cursor=1",
     "SPEECH OUTPUT: 'Filter by Category All Categories combo box.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "2. Tab to list item",
    ["BRAILLE LINE:  'soffice application Templates dialog Template List panel list Modern business letter sans-serif list item'",
     "     VISIBLE:  'Modern business letter sans-seri', cursor=1",
     "SPEECH OUTPUT: 'Template List panel.'",
     "SPEECH OUTPUT: 'List with 7 items.'",
     "SPEECH OUTPUT: 'Modern business letter sans-serif.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "3. Right to next list item",
    ["BRAILLE LINE:  'soffice application Templates dialog Template List panel list Modern business letter serif list item'",
     "     VISIBLE:  'Modern business letter serif lis', cursor=1",
     "SPEECH OUTPUT: 'Modern business letter serif.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Left"))
sequence.append(utils.AssertPresentationAction(
    "4. Left to previous list item",
    ["BRAILLE LINE:  'soffice application Templates dialog Template List panel list Modern business letter sans-serif list item'",
     "     VISIBLE:  'Modern business letter sans-seri', cursor=1",
     "SPEECH OUTPUT: 'Modern business letter sans-serif.'"]))

sequence.append(KeyComboAction("<Alt>F4"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
